# SAP Discovery Inbox
### On this page
  * [Overview](https://help.sap.com/docs/leanix/ea/sap-landscape-discovery-inbox#overview)
  * [Accessing the SAP Discovery Inbox from the Inventory](https://help.sap.com/docs/leanix/ea/sap-landscape-discovery-inbox#accessing-the-sap-discovery-inbox-from-the-inventory)
  * [Filtering and Searching in the Discovery Inbox](https://help.sap.com/docs/leanix/ea/sap-landscape-discovery-inbox#filtering-and-searching-in-the-discovery-inbox)
  * [Linking Discovered Items to Suggested Fact Sheets](https://help.sap.com/docs/leanix/ea/sap-landscape-discovery-inbox#linking-discovered-items-to-suggested-fact-sheets)
  * [Linking Beyond Suggested Fact Sheets](https://help.sap.com/docs/leanix/ea/sap-landscape-discovery-inbox#linking-beyond-suggested-fact-sheets)
  * [Linking Discovered Items to Fact Sheets in Bulk](https://help.sap.com/docs/leanix/ea/sap-landscape-discovery-inbox#linking-discovered-items-to-fact-sheets-in-bulk)
  * [Changing Existing Links to Fact Sheets](https://help.sap.com/docs/leanix/ea/sap-landscape-discovery-inbox#changing-existing-links-to-fact-sheets)
  * [Rejecting Discovered Items](https://help.sap.com/docs/leanix/ea/sap-landscape-discovery-inbox#rejecting-discovered-items)


View all
Discovered products, services, and extensions from your SAP landscape appear in the SAP discovery inbox. Learn how to create, link, and reject fact sheets related to discovered items.
